==> func_adl_servicex_xaodr25-1.1.0.25.2.12b3.tar.gz: func_adl_servicex_xaodr25-1.1.0.25.2.12b3/func_adl_servicex_xaodr25/xAOD/trackstate_v1.py <==
from __future__ import annotations
import ast
from typing import Tuple, TypeVar, Iterable
from func_adl import ObjectStream, func_adl_callback, func_adl_parameterized_call
from enum import Enum
import func_adl_servicex_xaodr25

_method_map = {
    'chi2': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'chi2',
        'return_type': 'float',
    },
    'chi2Ptr': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'chi2Ptr',
        'return_type': 'const float *',
    },
    'pathLength': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'pathLength',
        'return_type': 'double',
    },
    'pathLengthPtr': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'pathLengthPtr',
        'return_type': 'const double *',
    },
    'typeFlags': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'typeFlags',
        'return_type': 'uint64_t',
    },
    'typeFlagsPtr': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'typeFlagsPtr',
        'return_type': 'const uint64_t *',
    },
    'uncalibratedMeasurementLink': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'uncalibratedMeasurementLink',
        'return_type': 'ElementLink<DataVector<xAOD::UncalibratedMeasurement_v1>>',
    },
    'geometryId': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'geometryId',
        'return_type': 'uint64_t',
    },
    'surfaceLink': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'surfaceLink',
        'return_type': 'ElementLink<DataVector<xAOD::TrackSurface_v1>>',
    },
    'index': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'index',
        'return_type': 'unsigned int',
    },
    'usingPrivateStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'usingPrivateStore',
        'return_type': 'bool',
    },
    'usingStandaloneStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'usingStandaloneStore',
        'return_type': 'bool',
    },
    'hasStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'hasStore',
        'return_type': 'bool',
    },
    'hasNonConstStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'hasNonConstStore',
        'return_type': 'bool',
    },
    'clearDecorations': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'clearDecorations',
        'return_type': 'bool',
    },
    'trackIndices': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'trackIndices',
        'return_type': 'bool',
    },
    'auxdataConst': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'auxdataConst',
        'return_type': 'U',
    },
    'isAvailable': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'isAvailable',
        'return_type': 'bool',
    },
}

_enum_map = {      
}

T = TypeVar('T')


def _add_method_metadata(s: ObjectStream[T], a: ast.Call) -> Tuple[ObjectStream[T], ast.Call]:
    '''Add metadata for a collection to the func_adl stream if we know about it
    '''
    assert isinstance(a.func, ast.Attribute)
    if a.func.attr in _method_map:
        s_update = s.MetaData(_method_map[a.func.attr])

        s_update = s_update.MetaData({
            'metadata_type': 'inject_code',
            'name': 'xAODTracking/versions/TrackState_v1.h',
            'body_includes': ["xAODTracking/versions/TrackState_v1.h"],
        })


        s_update = s_update.MetaData({
            'metadata_type': 'inject_code',
            'name': 'xAODTracking',
            'link_libraries': ["xAODTracking"],
        })

        for md in _enum_map.get(a.func.attr, []):
            s_update = s_update.MetaData(md)
        return s_update, a
    else:
        return s, a


@func_adl_callback(_add_method_metadata)
class TrackState_v1:
    "A class"


    def chi2(self) -> float:
        "A method"
        ...

    def chi2Ptr(self) -> float:
        "A method"
        ...

    def pathLength(self) -> float:
        "A method"
        ...

    def pathLengthPtr(self) -> float:
        "A method"
        ...

    def typeFlags(self) -> int:
        "A method"
        ...

    def typeFlagsPtr(self) -> int:
        "A method"
        ...

    def uncalibratedMeasurementLink(self) -> func_adl_servicex_xaodr25.elementlink_datavector_xaod_uncalibratedmeasurement_v1__.ElementLink_DataVector_xAOD_UncalibratedMeasurement_v1__:
        "A method"
        ...

    def geometryId(self) -> int:
        "A method"
        ...

    def surfaceLink(self) -> func_adl_servicex_xaodr25.elementlink_datavector_xaod_tracksurface_v1__.ElementLink_DataVector_xAOD_TrackSurface_v1__:
        "A method"
        ...

    def index(self) -> int:
        "A method"
        ...

    def usingPrivateStore(self) -> bool:
        "A method"
        ...

    def usingStandaloneStore(self) -> bool:
        "A method"
        ...

    def hasStore(self) -> bool:
        "A method"
        ...

    def hasNonConstStore(self) -> bool:
        "A method"
        ...

    def clearDecorations(self) -> bool:
        "A method"
        ...

    def trackIndices(self) -> bool:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr25.type_support.cpp_generic_1arg_callback('auxdataConst', s, a, param_1))
    @property
    def auxdataConst(self) -> func_adl_servicex_xaodr25.type_support.index_type_forwarder[func_adl_servicex_xaodr25.str.str]:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr25.type_support.cpp_generic_1arg_callback('isAvailable', s, a, param_1))
    @property
    def isAvailable(self) -> func_adl_servicex_xaodr25.type_support.index_type_forwarder[func_adl_servicex_xaodr25.str.str]:
        "A method"
        ...

==> func_adl_servicex_xaodr25-2.2.2.25.2.41.tar.gz: func_adl_servicex_xaodr25-2.2.2.25.2.41/func_adl_servicex_xaodr25/xAOD/trackstate_v1.py <==
from __future__ import annotations
import ast
from typing import Tuple, TypeVar, Iterable
from func_adl import ObjectStream, func_adl_callback, func_adl_parameterized_call
from enum import Enum
import func_adl_servicex_xaodr25

_method_map = {
    'chi2': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'chi2',
        'return_type': 'float',
    },
    'chi2Ptr': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'chi2Ptr',
        'return_type': 'const float *',
    },
    'pathLength': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'pathLength',
        'return_type': 'double',
    },
    'pathLengthPtr': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'pathLengthPtr',
        'return_type': 'const double *',
    },
    'typeFlags': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'typeFlags',
        'return_type': 'uint64_t',
    },
    'typeFlagsPtr': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'typeFlagsPtr',
        'return_type': 'const uint64_t *',
    },
    'uncalibratedMeasurement': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'uncalibratedMeasurement',
        'return_type': 'const xAOD::UncalibratedMeasurement_v1 *',
    },
    'geometryId': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'geometryId',
        'return_type': 'uint64_t',
    },
    'surfaceIndex': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'surfaceIndex',
        'return_type': 'unsigned int',
    },
    'index': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'index',
        'return_type': 'unsigned int',
    },
    'usingPrivateStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'usingPrivateStore',
        'return_type': 'bool',
    },
    'usingStandaloneStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'usingStandaloneStore',
        'return_type': 'bool',
    },
    'hasStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'hasStore',
        'return_type': 'bool',
    },
    'hasNonConstStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'hasNonConstStore',
        'return_type': 'bool',
    },
    'clearDecorations': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'clearDecorations',
        'return_type': 'bool',
    },
    'trackIndices': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'trackIndices',
        'return_type': 'bool',
    },
    'auxdataConst': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'auxdataConst',
        'return_type': 'U',
    },
    'isAvailable': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackState_v1',
        'method_name': 'isAvailable',
        'return_type': 'bool',
    },
}

_enum_map = {      
}

T = TypeVar('T')


def _add_method_metadata(s: ObjectStream[T], a: ast.Call) -> Tuple[ObjectStream[T], ast.Call]:
    '''Add metadata for a collection to the func_adl stream if we know about it
    '''
    assert isinstance(a.func, ast.Attribute)
    if a.func.attr in _method_map:
        s_update = s.MetaData(_method_map[a.func.attr])

        s_update = s_update.MetaData({
            'metadata_type': 'inject_code',
            'name': 'xAODTracking/versions/TrackState_v1.h',
            'body_includes': ["xAODTracking/versions/TrackState_v1.h"],
        })


        s_update = s_update.MetaData({
            'metadata_type': 'inject_code',
            'name': 'xAODTracking',
            'link_libraries': ["xAODTracking"],
        })

        for md in _enum_map.get(a.func.attr, []):
            s_update = s_update.MetaData(md)
        return s_update, a
    else:
        return s, a


@func_adl_callback(_add_method_metadata)
class TrackState_v1:
    "A class"


    def chi2(self) -> float:
        "A method"
        ...

    def chi2Ptr(self) -> float:
        "A method"
        ...

    def pathLength(self) -> float:
        "A method"
        ...

    def pathLengthPtr(self) -> float:
        "A method"
        ...

    def typeFlags(self) -> int:
        "A method"
        ...

    def typeFlagsPtr(self) -> int:
        "A method"
        ...

    def uncalibratedMeasurement(self) -> func_adl_servicex_xaodr25.xAOD.uncalibratedmeasurement_v1.UncalibratedMeasurement_v1:
        "A method"
        ...

    def geometryId(self) -> int:
        "A method"
        ...

    def surfaceIndex(self) -> int:
        "A method"
        ...

    def index(self) -> int:
        "A method"
        ...

    def usingPrivateStore(self) -> bool:
        "A method"
        ...

    def usingStandaloneStore(self) -> bool:
        "A method"
        ...

    def hasStore(self) -> bool:
        "A method"
        ...

    def hasNonConstStore(self) -> bool:
        "A method"
        ...

    def clearDecorations(self) -> bool:
        "A method"
        ...

    def trackIndices(self) -> bool:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr25.type_support.cpp_generic_1arg_callback('auxdataConst', s, a, param_1))
    @property
    def auxdataConst(self) -> func_adl_servicex_xaodr25.type_support.index_type_forwarder[str]:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr25.type_support.cpp_generic_1arg_callback('isAvailable', s, a, param_1))
    @property
    def isAvailable(self) -> func_adl_servicex_xaodr25.type_support.index_type_forwarder[str]:
        "A method"
        ...
